Tortik
==================

Tortik is a frontend micro framework atop of Python Tornado making easier to develop SOA-based applications.

.. image:: https://travis-ci.org/glibin/tortik.svg
    :target: https://travis-ci.org/glibin/tortik

.. image:: https://coveralls.io/repos/glibin/tortik/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/glibin/tortik?branch=master

.. image:: https://img.shields.io/pypi/pyversions/tortik.svg
    :target: https://pypi.python.org/pypi/tortik/

.. image:: https://img.shields.io/pypi/v/tortik.svg
    :target: https://pypi.python.org/pypi/tortik



Short explanation of tortik features: `<http://glibin.github.io/tortik>`_

Documentation and installation instructions  `<http://tortik.readthedocs.org/en/latest/>`_


SOA (microservices) and tortik use cases at PyCon RU 2014 (in Russian) `<http://glibin.github.io/lections/pycon2014/>`_
